`timescale 1 ps / 1 ps

module a_tb ();

// Constants
parameter	REF_CLK_PERIOD 			= 7407;			//135MHz
parameter	MGMT_CLK_PERIOD 		= 10000;		//100MHz
parameter	PMA_WIDTH = 32;		// Specify your PMA width settings

// Registers
reg clock_tb;
reg mgmt_blk_clock_tb;
reg reset_tb;
reg tx_forceelecidle_tb;
reg rx_std_wa_patternalign_tb;
reg rx_std_byteorder_ena_tb;
reg [PMA_WIDTH - 1:0] tx_parallel_data_tb;
reg [3:0] tx_datak_tb;

// Wires
wire tx_ready_tb;
wire rx_ready_tb;
wire pll_locked_tb;
wire tx_serial_data_tb;
wire rx_serial_data_tb;
wire rx_is_lockedtoref_tb;
wire rx_is_lockedtodata_tb;
wire tx_clkout_tb;
wire rx_clkout_tb;
wire [PMA_WIDTH - 1:0] rx_parallel_data_tb;
wire [1:0] rx_patterndetect_tb;
wire [1:0] rx_syncstatus_tb;
wire rx_std_byteorder_flag_tb;

// External loopback TX -> RX
assign		rx_serial_data_tb = tx_serial_data_tb;

// Start the test

initial
begin
	
	reset_tb 		= 1'b0;
	tx_forceelecidle_tb	= 1'b0;	
	rx_std_wa_patternalign_tb = 1'b0;
	rx_std_byteorder_ena_tb = 1'b0;
	tx_datak_tb = 4'b1111;
	tx_parallel_data_tb = 32'hBCF7FBFD;

	#50000
	reset_tb = 1'b1;
	#100000
	reset_tb = 1'b0;

	// Start manual alignment
	#50000000
	rx_std_wa_patternalign_tb = 1'b1;
	#100000
	rx_std_wa_patternalign_tb = 1'b0;

	// Start byte ordering
	#10000000
	rx_std_byteorder_ena_tb = 1'b1;
	#100000
	rx_std_byteorder_ena_tb = 1'b0;


	// Swap the MSByte and LSByte
	#10000000
	tx_datak_tb = 4'b1110;
	tx_parallel_data_tb = 32'h3CBC1C00;

	// Start byte ordering
	#10000000
	rx_std_byteorder_ena_tb = 1'b1;
	#100000
	rx_std_byteorder_ena_tb = 1'b0;




end


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
      //  Clocks

//reference clock
initial
begin
  clock_tb = 1;
  forever
    #(REF_CLK_PERIOD/2) clock_tb = !clock_tb;
end			

// MGMT reference clock
initial
begin
  mgmt_blk_clock_tb = 1;
  forever
    #(MGMT_CLK_PERIOD/2) mgmt_blk_clock_tb = !mgmt_blk_clock_tb;
end


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// ################################################################

a 	DUT	(
	.mgmt_clk			(mgmt_blk_clock_tb),
	.tx_pll_refclk			(clock_tb),
	.reconfig_busy			(reconfig_busy_tb),
	.rx_serial_data			(rx_serial_data_tb),
	.tx_ready			(tx_ready_tb),
	.rx_ready			(rx_ready_tb),
	.pll_locked			(pll_locked_tb),
	.tx_serial_data			(tx_serial_data_tb),
	.rx_is_lockedtoref		(rx_is_lockedtoref_tb),
	.rx_is_lockedtodata		(rx_is_lockedtodata_tb),
	.tx_clkout			(tx_clkout_tb),
	.rx_clkout			(rx_clkout_tb),
	.rx_parallel_data		(rx_parallel_data_tb),
	.reset				(reset_tb),
	.tx_forceelecidle		(tx_forceelecidle_tb),
	.rx_patterndetect		(rx_patterndetect_tb),
	.rx_std_wa_patternalign		(rx_std_wa_patternalign_tb),
	.rx_std_byteorder_ena		(rx_std_byteorder_ena_tb),
	.rx_std_byteorder_flag		(rx_std_byteorder_flag_tb),
	.tx_parallel_data		(tx_parallel_data_tb),
	.rx_syncstatus			(rx_syncstatus_tb),
	.tx_datak			(tx_datak_tb)
);

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

endmodule
